@@ -19,16 +19,16 @@ using namespace panda::date;
 using std::string_view;
 using xs::lib::sv2string_view;
 
-static const char* DATE_CLASS    = "Panda::Date";
-static const char* DATEREL_CLASS = "Panda::Date::Rel";
-static const char* DATEINT_CLASS = "Panda::Date::Int";
+const char*const DATE_CLASS    = "Panda::Date";
+const char*const DATEREL_CLASS = "Panda::Date::Rel";
+const char*const DATEINT_CLASS = "Panda::Date::Int";
 
 inline const Timezone* tzget_required (pTHX_ SV* zone) {
-    return tzget(zone != NULL && SvOK(zone) ? sv2string_view(zone) : string_view());
+    return tzget(zone != NULL && SvOK(zone) ? sv2string_view(aTHX_ zone) : string_view());
 }
 
 inline const Timezone* tzget_optional (pTHX_ SV* zone) {
-    return zone ? tzget(SvOK(zone) ? sv2string_view(zone) : string_view()) : NULL;
+    return zone ? tzget(SvOK(zone) ? sv2string_view(aTHX_ zone) : string_view()) : NULL;
 }
 
 inline void daterel_chkro (pTHX_ const DateRel* THIS) {
